{% for master in bare.masters -%}
{{ master.hostname }} ansible_host={{ master.ip }} ansible_ssh_private_key_file='keys/{{ master.hostname }}/private_key'
{% endfor -%}
{% for node in bare.nodes -%}
{{ node.hostname }} ansible_host={{ node.ip }} ansible_ssh_private_key_file='keys/{{ node.hostname }}/private_key'
{% endfor %}
[k8sdc:children]
k8sdc-masters
k8sdc-nodes
etcd
k8sdc-ca
fileserver

[k8sdc:vars]
ansible_ssh_user=k8sdc
ansible_connection=ssh

[k8sdc-masters]
{% for master in bare.masters -%}
{{ master.hostname }}
{% endfor %}
[k8sdc-nodes]
{% for node in bare.nodes -%}
{{ node.hostname }}
{% endfor %}
[etcd]
{% for etcd in bare.etcd -%}
{{ etcd }}
{% endfor %}
[fileserver]
{{ bare.fileserver[0] }}

[k8sdc-ca]
{{ bare.k8sdc_ca[0] }}
