apiVersion: v1
kind: Config
current-context: kubelet-to-{{ cluster_name }}
preferences: {}
clusters:
- cluster:
    certificate-authority: /etc/kubernetes/certs/k8sdc-ca.crt
    server: https://{{ groups['k8sdc-masters'][0] }}:{{ kubernetes_api_port }}
  name: {{ cluster_name }}
contexts:
- context:
    cluster: {{ cluster_name }}
    user: kubelet
  name: kubelet-to-{{ cluster_name }}
current-context: kubelet-to-{{ cluster_name }}
users:
- name: kubelet
  user:
    token: {{ node_token_values[inventory_hostname]['system_kubelet'] | b64decode }}
